selectbox - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- SelectBox
- SelectBox.add
- SelectBox.remove
- SelectBox.clear

# SelectBox

SelectBox([multiple, [expand]]) -> SelectBox widget

Subclasses from VBox. Like a html select box.

You can access SelectBox.values to get a set of all selected values.

### Arguments

multiple
  If set to True, multiple options can be selected.
expand
  If set to True (default) all widgets will expand to be the same width.

## SelectBox.add

SelectBox.add(label, value) -> Option widget

Add an option to SelectBox.

### Arguments

label
  The text or widget to be displayed as the option.
value
  The value of the option (not displayed).

## SelectBox.remove

SelectBox.remove(option) -> None

Remove option from SelectBox.

### Arguments

option
  Can ether be a string representing an option's value or the option widget.

## SelectBox.clear

SelectBox.clear() -> None

clears all options from SelectBox.